import { safeLoadBtModule } from "..";
import { BT_MODULE } from "../constants";
import { btModulesLoadConfig } from "../types";
import assetLoader from "@braintree/asset-loader";

jest.mock("@braintree/asset-loader", () => {
  return {
    loadScript: jest.fn(),
    loadStylesheet: jest.fn(),
  };
});

describe("safeLoadBtModule", () => {
  const version = "3.109.0";

  it("should attempt to load BT module", async () => {
    const { id, script } = btModulesLoadConfig.client;

    await safeLoadBtModule(btModulesLoadConfig.client, version);

    const scriptSrc = `https://js.braintreegateway.com/web/${version}/js/${script.minified}`;
    const loadScriptOptions = {
      id: `${id}-${version}`,
      src: scriptSrc,
    };

    expect(assetLoader.loadScript).toHaveBeenCalledWith(loadScriptOptions);
  });

  it("should not load BT module if same version already exists", async () => {
    window.braintree = {
      [BT_MODULE.Client]: {
        create: jest.fn(),
        VERSION: version,
      },
    };

    const loadResp = await safeLoadBtModule(
      btModulesLoadConfig.client,
      version
    );

    expect(assetLoader.loadScript).not.toHaveBeenCalled();
    expect(loadResp).toBe(true);
  });

  it("should not load BT module and return error if module on different version already exists", async () => {
    window.braintree = {
      [BT_MODULE.Client]: {
        create: jest.fn(),
        VERSION: "3.96.0",
      },
    };

    try {
      await safeLoadBtModule(btModulesLoadConfig.client, version);
    } catch (error) {
      expect(error).toStrictEqual(
        new Error(
          `client already loaded with version 3.96.0 cannot load version ${version}`
        )
      );
    }

    expect(assetLoader.loadScript).not.toHaveBeenCalled();
  });

  it("should not load BT module and return error if no version specified", async () => {
    try {
      await safeLoadBtModule(btModulesLoadConfig.client, "");
    } catch (error) {
      expect(error).toStrictEqual(
        new Error("Attempted to load client without specifying version")
      );
    }

    expect(assetLoader.loadScript).not.toHaveBeenCalled();
  });
});
